==> ejc-assistrmat-impl-3.0.0-20220909.014939-179-sources.jar: com/ejianc/business/outrmat/delivery/bean/OutRmatDeliveryDetailEntity.java <==
package com.ejianc.business.outrmat.delivery.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_delivery_detail")
public class OutRmatDeliveryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="calculate_unit_name")
    private String calculateUnitName; // 计量单位名称
    @TableField(value="calculate_unit_id")
    private Long calculateUnitId; // 计量单位主键
    @TableField(value="rent_unit_id")
    private Long rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="calculate_num")
    private BigDecimal calculateNum; // 计量数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 库存可用数量
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="standard_offset_rate")
    private BigDecimal standardOffsetRate; // 标准偏差率
    @TableField(value="actual_offset_rate")
    private BigDecimal actualOffsetRate; // 实际偏差率
    @TableField(value="require_detail_flag")
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    @TableField(value="rent_detail_date")
    private Date rentDetailDate; // 计租日期
    @TableField(value="rent_type")
    private Integer rentType; // 计租方式
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20221202.024741-319-sources.jar: com/ejianc/business/outrmat/delivery/bean/OutRmatDeliveryDetailEntity.java <==
package com.ejianc.business.outrmat.delivery.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_delivery_detail")
public class OutRmatDeliveryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="calculate_unit_name")
    private String calculateUnitName; // 计量单位名称
    @TableField(value="calculate_unit_id")
    private Long calculateUnitId; // 计量单位主键
    @TableField(value="rent_unit_id")
    private Long rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="calculate_num")
    private BigDecimal calculateNum; // 计量数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="use_num")
    private BigDecimal useNum; // 库存可用数量
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="standard_offset_rate")
    private BigDecimal standardOffsetRate; // 标准偏差率
    @TableField(value="actual_offset_rate")
    private BigDecimal actualOffsetRate; // 实际偏差率
    @TableField(value="require_detail_flag")
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    @TableField(value="rent_detail_date")
    private Date rentDetailDate; // 计租日期
    @TableField(value="rent_type")
    private Integer rentType; // 计租方式
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "rent_calculation_type")
    private Integer rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value = "trans_scale")
    private BigDecimal transScale; // 转换系数

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public Integer getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(Integer rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
